import {select, json, tsv, geoPath, geoNaturalEarth1} from 'd3';
import {feature} from 'topojson';

const svg = select('svg');


const projection = geoNaturalEarth1();
//instance of geoPath
const pathGenerator = geoPath().projection(projection);

svg.append('path')
		.attr('class','sphere')
		.attr('d', pathGenerator({type : 'Sphere'}));

Promise.all([
	tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')

]).then(([tsvData, topoJsondata]) => {
  			 //es6 destructuring data syntax
  			 //reduce(), built-in javascript function
  		   //first argument : function with arguments (accumulator, data)
  			 //second argument : initial value of accumulator
  	//1ère façon de faire
  	const countryName = tsvData.reduce((accumulator, d) => {
      //d.iso_n3 => d.id dans .tsv, voir dans la documentation de world-atlas
      accumulator[d.iso_n3] = d.name;
      return accumulator;
    
    }, {});
  
  	/*
    2ème façon de faire
  	const countryName = {};
  	tsvData.forEach(d => {
      countryName[d.iso_n3] = d.name;
    });
    */
  
  	const countries = feature(topoJsondata, topoJsondata.objects.countries);
  	svg.selectAll('path')
        .data(countries.features)
  			.enter().append('path')
  				.attr('class', 'country')
        .attr('d', pathGenerator)
  			.append('title')
  				.text(d => countryName[d.id]);


});
       

//d.name for title
//d.iso_n3 for id, for the .tsv, find the infomation on world-atlas documentation
/*
json('https://unpkg.com/world-atlas@1.1.4/world/110m.json')
	.then(data => {
  
  		const countries = feature(data, data.objects.countries);
      console.log(data);
  		console.log(countries);
  		
  		
  		//this is a data-join
  		const paths = svg.selectAll('path')
      	.data(countries.features);
  		paths.enter().append('path')
  			.attr('d', d => pathGenerator(d));
      
  	
  		svg.selectAll('path')
        .data(countries.features)
  			.enter().append('path')
  				.attr('class', 'country')
        .attr('d', pathGenerator)
  			.append('title');
  	
	});
  
*